@@ -14,11 +14,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-from PyQt5.Qt import pyqtSignal, QObject
+from PyQt5.QtCore import pyqtSignal, QObject
 
 class WithValueChangedConfiguration(QObject):
-    def __init__(self, inner):
-        super().__init__()
+    def __init__(self, parent, inner):
+        super().__init__(parent)
         self._inner = inner
     
     onValueChanged = pyqtSignal(str, object)
